@@ -11,8 +11,9 @@ you are welcome to create your own metrics and to contribute to source code.
 
 import numpy as np
 import pandas as pd
-import statsmodels.regression.linear_model as sm_linear
-import statsmodels.tools.tools as sm_tools
+from statsmodels.regression.linear_model import OLS
+from statsmodels.tools.tools import add_constant
+from scipy.stats import ttest_1samp
 
 from .utils import get_annualization_factor, align
 
@@ -44,8 +45,7 @@ __all__ = [
 
 
 def summary(portfolio, benchmark):
-    """
-    Calculates summary statistics for a `portfolio`.
+    """Calculates summary statistics for a `portfolio`.
 
     Computed metrics:
 
@@ -95,9 +95,11 @@ def summary(portfolio, benchmark):
             'Sharpe Ratio': sharpe_ratio(portfolio.returns),
             'Omega Ratio': omega_ratio(portfolio.returns),
             'Sortino Ratio': sortino_ratio(portfolio.returns),
-            'Mean Excess Return, %': mean_excess_return(portfolio.returns, benchmark.returns) * 100,
             'Benchmark Correlation': benchmark_correlation(portfolio.returns, benchmark.returns),
+            'Mean Excess Return, %': mean_excess_return(portfolio.returns, benchmark.returns) * 100,
+            'Excess Returns t-stat': _mean_excess_return_tstat(portfolio.returns, benchmark.returns),
             'Alpha, %': alpha(portfolio.returns, benchmark.returns) * 100,
+            'Alpha t-stat': _alpha_tstat(portfolio.returns, benchmark.returns),
             'Beta': beta(portfolio.returns, benchmark.returns),
         },
         name=portfolio.name
@@ -105,8 +107,7 @@ def summary(portfolio, benchmark):
 
 
 def cumulative_returns(returns):
-    """
-    Calculates Cumulative Returns of portfolio returns.
+    """Calculates Cumulative Returns of portfolio returns.
 
     Parameters
     ----------
@@ -126,9 +127,33 @@ def cumulative_returns(returns):
     return (1 + returns).cumprod() - 1
 
 
-def total_return(returns):
+def drawdown(returns):
+    """Calculates Drawdown of portfolio returns.
+
+    Drawdown of portfolio is the relative difference between high water mark (cumulative maximum of 
+    the cumulative returns) and cumulative returns:
+
+    .. math::
+        DD = -\\frac{High\\;Water\\;Mark - Cumulative\\;Returns}{High\\;Water\\;Mark}
+
+    Parameters
+    ----------
+    returns : pd.Series
+        Returns of a portfolio or a benchmark.
+
+    Returns
+    -------
+    pd.Series
+        Drawdown.
     """
-    Calculates Total Return of portfolio returns.
+
+    equity = cumulative_returns(returns) + 1
+    high_water_mark = equity.cummax()
+    return -(high_water_mark - equity) / high_water_mark
+
+
+def total_return(returns):
+    """Calculates Total Return of portfolio returns.
 
     Parameters
     ----------
@@ -149,8 +174,7 @@ def total_return(returns):
 
 
 def annual_return(returns):
-    """
-    Calculates Annual Return of portfolio returns as CAGR.
+    """Calculates Annual Return of portfolio returns as CAGR.
 
     CAGR (Compounded Annual Growth Rate) calculated as:
 
@@ -174,13 +198,12 @@ def annual_return(returns):
 
 
 def annual_volatility(returns):
-    """
-    Calculates Annual Volatility of portfolio returns.
+    """Calculates Annual Volatility of portfolio returns.
 
     Annual Volatility of the portfolio is the annualized standard deviation of portfolio returns:
 
     .. math::
-        \\sigma_r * \\sqrt{Number\;of\;Periods\;in\;a\;Year}
+        \\sigma_r * \\sqrt{Number\\;of\\;Periods\\;in\\;a\\;Year}
 
     Parameters
     ----------
@@ -198,8 +221,7 @@ def annual_volatility(returns):
 
 
 def mean_return(returns):
-    """
-    Calculates Mean Return of portfolio returns.
+    """Calculates Mean Return of portfolio returns.
 
     Mean Return is simple expected value:
 
@@ -221,8 +243,7 @@ def mean_return(returns):
 
 
 def rolling_mean_return(returns, window=None):
-    """
-    Calculates rolling Mean Return of portfolio returns.
+    """Calculates rolling Mean Return of portfolio returns.
 
     See :func:`~pqr.metrics.mean_return`.
 
@@ -244,8 +265,7 @@ def rolling_mean_return(returns, window=None):
 
 
 def win_rate(returns):
-    """
-    Calculates Win Rate of portfolio returns.
+    """Calculates Win Rate of portfolio returns.
 
     Win Rate of a portfolio is simple ratio of number of periods with positive returns and total
     number of trading periods:
@@ -270,8 +290,7 @@ def win_rate(returns):
 
 
 def rolling_win_rate(returns, window=None):
-    """
-    Calculates rolling Win Rate of portfolio returns.
+    """Calculates rolling Win Rate of portfolio returns.
 
     See :func:`~pqr.metrics.win_rate`.
 
@@ -293,8 +312,7 @@ def rolling_win_rate(returns, window=None):
 
 
 def volatility(returns):
-    """
-    Calculates Volatility of portfolio returns.
+    """Calculates Volatility of portfolio returns.
 
     Volatility of the portfolio returns is the standard deviation:
 
@@ -316,8 +334,7 @@ def volatility(returns):
 
 
 def rolling_volatility(returns, window=None):
-    """
-    Calculates rolling Volatility of a `portfolio`.
+    """Calculates rolling Volatility of a `portfolio`.
 
     See :func:`~pqr.metrics.volatility`.
 
@@ -339,14 +356,13 @@ def rolling_volatility(returns, window=None):
 
 
 def max_drawdown(returns):
-    """
-    Calculates Maximum Drawdown of portfolio returns.
+    """Calculates Maximum Drawdown of portfolio returns.
 
     Maximum Drawdown of portfolio is the highest relative difference between high water mark
     (cumulative maximum of the cumulative returns) and cumulative returns:
 
     .. math::
-        MDD = -\max{\\frac{HWM - Cumulative\;Returns}{HWM}}
+        MDD = \\max\\{Drawdown\\}
 
     Parameters
     ----------
@@ -359,14 +375,11 @@ def max_drawdown(returns):
         Maximum Drawdown.
     """
 
-    cumsum_returns = returns.cumsum()
-    underwater = cumsum_returns - cumsum_returns.cummax()
-    return underwater.min()
+    return drawdown(returns).min()
 
 
 def rolling_max_drawdown(returns, window=None):
-    """
-    Calculates rolling Maximum Drawdown of portfolio returns.
+    """Calculates rolling Maximum Drawdown of portfolio returns.
 
     See :func:`~pqr.metrics.max_drawdown`.
 
@@ -388,14 +401,13 @@ def rolling_max_drawdown(returns, window=None):
 
 
 def value_at_risk(returns, confidence_level=0.95):
-    """
-    Calculates Value at Risk of portfolio returns.
+    """Calculates Value at Risk of portfolio returns.
 
     VaR shows the amount of potential loss that could happen in a portfolio with given
     `confidence_level`:
 
     .. math::
-        VaR = -\\inf\{F_r(r) > Confidence\;Level\}
+        VaR = -\\inf\\{F_r(r) > Confidence\\;Level\\}
 
     Parameters
     ----------
@@ -414,8 +426,7 @@ def value_at_risk(returns, confidence_level=0.95):
 
 
 def rolling_value_at_risk(returns, confidence_level=0.95, window=None):
-    """
-    Calculates rolling Value at Risk of portfolio returns.
+    """Calculates rolling Value at Risk of portfolio returns.
 
     See :func:`~pqr.metrics.value_at_risk`.
 
@@ -439,15 +450,13 @@ def rolling_value_at_risk(returns, confidence_level=0.95, window=None):
 
 
 def expected_tail_loss(returns, confidence_level=0.95):
-    """
-    Calculates Expected Tail Loss of portfolio returns.
+    """Calculates Expected Tail Loss of portfolio returns.
 
     Expected Tail Loss shows the average of the values that fall beyond the VaR, calculated with
     given `confidence_level`:
 
     .. math::
-        ETL = \\frac{\\sum_{i=1}^{n}r_i\cdot[r_i \le VaR]}
-        {\\sum_{i=1}^{n}[r_i \le VaR]}
+        ETL = \\frac{\\sum_{i=1}^{n}r_i\\cdot[r_i \\le VaR]}{\\sum_{i=1}^{n}[r_i \\le VaR]}
 
     Parameters
     ----------
@@ -467,8 +476,7 @@ def expected_tail_loss(returns, confidence_level=0.95):
 
 
 def rolling_expected_tail_loss(returns, confidence_level=0.95, window=None):
-    """
-    Calculates rolling Expected Tail Loss of portfolio returns.
+    """Calculates rolling Expected Tail Loss of portfolio returns.
 
     See :func:`~pqr.metrics.expected_tail_loss`.
 
@@ -493,8 +501,7 @@ def rolling_expected_tail_loss(returns, confidence_level=0.95, window=None):
 
 
 def rachev_ratio(returns, reward_cutoff=0.95, risk_cutoff=0.05, risk_free_rate=0):
-    """
-    Calculates Rachev Ratio (R-Ratio) of portfolio returns.
+    """Calculates Rachev Ratio (R-Ratio) of portfolio returns.
 
     Rachev Ratio calculated as ETR (Expected Tail Return) divided by ETL (Expected Tail Return) of
     adjusted by `risk_free_rate` returns:
@@ -529,8 +536,7 @@ def rachev_ratio(returns, reward_cutoff=0.95, risk_cutoff=0.05, risk_free_rate=0
 
 def rolling_rachev_ratio(returns, reward_cutoff=0.95, risk_cutoff=0.05, risk_free_rate=0,
                          window=None):
-    """
-    Calculates rolling Rachev Ratio (R-Ratio) of portfolio returns.
+    """Calculates rolling Rachev Ratio (R-Ratio) of portfolio returns.
 
     See :func:`~pqr.metrics.rachev_ratio`.
 
@@ -560,8 +566,7 @@ def rolling_rachev_ratio(returns, reward_cutoff=0.95, risk_cutoff=0.05, risk_fre
 
 
 def calmar_ratio(returns):
-    """
-    Calculates Calmar Ratio of portfolio returns.
+    """Calculates Calmar Ratio of portfolio returns.
 
     Calmar Ratio is annual return (CAGR) divided by maximum drawdown of the period:
 
@@ -583,8 +588,7 @@ def calmar_ratio(returns):
 
 
 def rolling_calmar_ratio(returns, window=None):
-    """
-    Calculates rolling Calmar Ratio of portfolio returns.
+    """Calculates rolling Calmar Ratio of portfolio returns.
 
     See :func:`~pqr.metrics.calmar_ratio`.
 
@@ -606,8 +610,7 @@ def rolling_calmar_ratio(returns, window=None):
 
 
 def sharpe_ratio(returns, risk_free_rate=0):
-    """
-    Calculates Sharpe Ratio of portfolio returns.
+    """Calculates Sharpe Ratio of portfolio returns.
 
     Sharpe Ratio calculated as annualized ratio between mean and volatility of adjusted by
     `risk_free_rate` returns:
@@ -634,8 +637,7 @@ def sharpe_ratio(returns, risk_free_rate=0):
 
 
 def rolling_sharpe_ratio(returns, risk_free_rate=0, window=None) -> pd.Series:
-    """
-    Calculates rolling Sharpe Ratio of portfolio returns.
+    """Calculates rolling Sharpe Ratio of portfolio returns.
 
     See :func:`~pqr.metrics.sharpe_ratio`.
 
@@ -660,8 +662,7 @@ def rolling_sharpe_ratio(returns, risk_free_rate=0, window=None) -> pd.Series:
 
 
 def omega_ratio(returns, required_return=0):
-    """
-    Calculates Omega Ratio of portfolio returns.
+    """Calculates Omega Ratio of portfolio returns.
 
     Omega Ratio calculated as the area of the probability distribution function of returns above
     `required_return` divided by the area under `required_return`:
@@ -690,8 +691,7 @@ def omega_ratio(returns, required_return=0):
 
 
 def rolling_omega_ratio(returns, required_return=0, window=None) -> pd.Series:
-    """
-    Calculates rolling Omega Ratio of a portfolio returns.
+    """Calculates rolling Omega Ratio of a portfolio returns.
 
     See :func:`~pqr.metrics.omega_ratio`.
 
@@ -716,8 +716,7 @@ def rolling_omega_ratio(returns, required_return=0, window=None) -> pd.Series:
 
 
 def sortino_ratio(returns, minimum_acceptable_return=0):
-    """
-    Calculates Sortino Ratio of portfolio returns.
+    """Calculates Sortino Ratio of portfolio returns.
 
     Sortino Ratio is the mean of adjusted by `minimum_acceptable_return` (mar) `portfolio` returns
     divided by Downside Risk:
@@ -748,8 +747,7 @@ def sortino_ratio(returns, minimum_acceptable_return=0):
 
 
 def rolling_sortino_ratio(returns, minimum_acceptable_return=0, window=None):
-    """
-    Calculates rolling Sortino Ratio of portfolio returns.
+    """Calculates rolling Sortino Ratio of portfolio returns.
 
     See :func:`~pqr.metrics.sortino_ratio`.
 
@@ -773,60 +771,8 @@ def rolling_sortino_ratio(returns, minimum_acceptable_return=0, window=None):
     return _roll(returns, metric=sortino_ratio, window=window, minimum_acceptable_return=0)
 
 
-def mean_excess_return(returns, benchmark):
-    """
-    Calculates Mean Excess Return of portfolio returns.
-
-    Mean Excess Return is the mean difference between portfolio `returns` and `benchmark` returns:
-
-    .. math::
-        MER = E(r_{portfolio} - r_{benchmark})
-
-    Parameters
-    ----------
-    returns : pd.Series
-        Returns of a portfolio or a benchmark.
-    benchmark : pd.Series
-        Benchmark for the portfolio to beat.
-
-    Returns
-    -------
-    float
-        Mean Excess Return.
-    """
-
-    adjusted_returns = _adjust_returns(returns, benchmark)
-    return mean_return(adjusted_returns)
-
-
-def rolling_mean_excess_return(returns, benchmark, window=None) -> pd.Series:
-    """
-    Calculates rolling Mean Excess Return of portfolio returns.
-
-    See :func:`~pqr.metrics.mean_excess_return`.
-
-    Parameters
-    ----------
-    returns : pd.Series
-        Returns of a portfolio or a benchmark.
-    benchmark : pd.Series
-        Benchmark for the portfolio to beat.
-    window : int > 0, optional
-        Number of observations in a rolling window. If not passed, `window` equals to approximate
-        number of periods in a year.
-
-    Returns
-    -------
-    pd.Series
-        Rolling Mean Excess Return.
-    """
-
-    return _roll(returns, benchmark, metric=mean_excess_return, window=window)
-
-
 def benchmark_correlation(returns, benchmark):
-    """
-    Calculates Benchmark Correlation of portfolio returns.
+    """Calculates Benchmark Correlation of portfolio returns.
 
     Benchmark Correlation is the simple spearman correlation between portfolio `returns` and
     `benchmark` returns:
@@ -852,8 +798,7 @@ def benchmark_correlation(returns, benchmark):
 
 
 def rolling_benchmark_correlation(returns, benchmark, window=None):
-    """
-    Calculates rolling Benchmark Correlation of portfolio returns.
+    """Calculates rolling Benchmark Correlation of portfolio returns.
 
     See :func:`~pqr.metrics.benchmark_correlation`.
 
@@ -876,9 +821,57 @@ def rolling_benchmark_correlation(returns, benchmark, window=None):
     return _roll(returns, benchmark, metric=benchmark_correlation, window=window)
 
 
-def alpha(returns, benchmark, risk_free_rate=0):
+def mean_excess_return(returns, benchmark):
+    """Calculates Mean Excess Return of portfolio returns.
+
+    Mean Excess Return is the mean difference between portfolio `returns` and `benchmark` returns:
+
+    .. math::
+        MER = E(r_{portfolio} - r_{benchmark})
+
+    Parameters
+    ----------
+    returns : pd.Series
+        Returns of a portfolio or a benchmark.
+    benchmark : pd.Series
+        Benchmark for the portfolio to beat.
+
+    Returns
+    -------
+    float
+        Mean Excess Return.
     """
-    Calculates Alpha of portfolio returns.
+
+    adjusted_returns = _adjust_returns(returns, benchmark)
+    return mean_return(adjusted_returns)
+
+
+def rolling_mean_excess_return(returns, benchmark, window=None) -> pd.Series:
+    """Calculates rolling Mean Excess Return of portfolio returns.
+
+    See :func:`~pqr.metrics.mean_excess_return`.
+
+    Parameters
+    ----------
+    returns : pd.Series
+        Returns of a portfolio or a benchmark.
+    benchmark : pd.Series
+        Benchmark for the portfolio to beat.
+    window : int > 0, optional
+        Number of observations in a rolling window. If not passed, `window` equals to approximate
+        number of periods in a year.
+
+    Returns
+    -------
+    pd.Series
+        Rolling Mean Excess Return.
+    """
+
+    return _roll(returns, benchmark, metric=mean_excess_return, window=window)
+
+
+def alpha(returns, benchmark, risk_free_rate=0):
+    """Calculates Alpha of portfolio returns.
 
     Alpha is the coefficient :math:`\\alpha` in the estimated regression of portfolio `returns` per
     `benchmark` returns (both are adjusted by `risk_free_rate`):
@@ -901,12 +894,11 @@ def alpha(returns, benchmark, risk_free_rate=0):
         Alpha.
     """
 
-    return _alpha_beta(returns, benchmark, risk_free_rate).iloc[0]
+    return _alpha_beta(returns, benchmark, risk_free_rate).params.iloc[0]
 
 
 def rolling_alpha(returns, benchmark, risk_free_rate=0, window=None):
-    """
-    Calculates rolling Alpha of portfolio returns.
+    """Calculates rolling Alpha of portfolio returns.
 
     See :func:`~pqr.metrics.alpha`.
 
@@ -934,8 +926,7 @@ def rolling_alpha(returns, benchmark, risk_free_rate=0, window=None):
 
 
 def beta(returns, benchmark, risk_free_rate=0):
-    """
-    Calculates Beta of portfolio returns.
+    """Calculates Beta of portfolio returns.
 
     Beta is the coefficient :math:`\\beta` in the estimated regression of portfolio `returns` per
     `benchmark` returns (both are adjusted by `risk_free_rate`):
@@ -958,12 +949,11 @@ def beta(returns, benchmark, risk_free_rate=0):
         Beta.
     """
 
-    return _alpha_beta(returns, benchmark, risk_free_rate).iloc[1]
+    return _alpha_beta(returns, benchmark, risk_free_rate).params.iloc[1]
 
 
 def rolling_beta(returns, benchmark, risk_free_rate=0, window=None) -> pd.Series:
-    """
-    Calculates rolling Beta of portfolio returns.
+    """Calculates rolling Beta of portfolio returns.
 
     See :func:`~pqr.metrics.beta`.
 
@@ -990,6 +980,15 @@ def rolling_beta(returns, benchmark, risk_free_rate=0, window=None) -> pd.Series
     return _roll(returns, benchmark, metric=beta, window=window, risk_free_rate=0)
 
 
+def _alpha_tstat(returns, benchmark, risk_free_rate=0):
+    return _alpha_beta(returns, benchmark, risk_free_rate).tvalues.iloc[0]
+
+
+def _mean_excess_return_tstat(returns, benchmark):
+    excess_returns = _adjust_returns(returns, benchmark)
+    return ttest_1samp(excess_returns, 0, alternative='greater').statistic
+
+
 def _adjust_returns(returns, adjustment):
     if isinstance(adjustment, pd.Series):
         returns, adjustment = align(returns, adjustment)
@@ -1000,22 +999,21 @@ def _alpha_beta(returns, benchmark, risk_free_rate=0):
     adjusted_returns = _adjust_returns(returns, risk_free_rate)
     adjusted_benchmark = _adjust_returns(benchmark, risk_free_rate)
     adjusted_returns, adjusted_benchmark = align(adjusted_returns, adjusted_benchmark)
-    x = sm_tools.add_constant(adjusted_benchmark)
-    est = sm_linear.OLS(adjusted_returns, x).fit()
-    return est.params
+    x = add_constant(adjusted_benchmark)
+    est = OLS(adjusted_returns, x).fit()
+    return est
 
 
 def _roll(*returns, metric, window=None, **kwargs):
     if window is None:
         window = get_annualization_factor(returns[0])
 
-    common_index = returns[0].index
-    for r in returns:
-        common_index = common_index.intersection(r.index)
+    returns = align(*returns)
+    index = returns[0].index
 
-    values = [np.nan] * (window - 1)
-    for i in range(window, len(common_index) + 1):
-        idx = common_index[i - window:i]
+    values = []
+    for i in range(window, len(index) + 1):
+        idx = index[i - window:i]
         rets = [r.loc[idx] for r in returns]
         values.append(metric(*rets, **kwargs))
-    return pd.Series(values, index=common_index)
+    return pd.Series(values, index=index[window-1:])
